@@ -101,15 +101,10 @@ def view_device_info(options):
             result = SerializedFile.get_connected_info(name=name)
             Printer.print(result)
         else:
-            node = DictObject(device='',
-                              testcases=options.showed_testcases,
-                              cmdlines=options.showed_cmdlines,
-                              testcase=options.testcase.strip())
+            node = DictObject(device='')
             if host:
                 node.device = DEVICES_DATA.get_address_from_name(host)
 
-            other and node.update(testcase=other)
-
             DEVICES_DATA.view(**node)
         sys.exit(ECODE.SUCCESS)
 
@@ -254,11 +249,6 @@ class Cli:
             help="host address or host name"
         ),
 
-        parser.add_argument(
-            '--testcase', type=str, default='',
-            help="showing test case data of device"
-        ),
-
         parser.add_argument(
             '--filename', type=str, default='',
             help="file name"
@@ -269,16 +259,6 @@ class Cli:
             help="device status"
         ),
 
-        parser.add_argument(
-            '--showed-testcases', action='store_true',
-            help="showing test cases data of device"
-        ),
-
-        parser.add_argument(
-            '--showed-cmdlines', action='store_true',
-            help="showing command lines data of device"
-        ),
-
         parser.add_argument(
             '--saved', action='store_true',
             help="saving devices info to devices_info.yaml"
@@ -317,7 +297,7 @@ class Cli:
         parser.add_argument(
             'command', type=str, nargs='?', default='',
             help='command must be either app, configure, connect, '
-                 'destroy, disconnect, execute, gui, info, load, '
+                 'destroy, disconnect, execute, gui, info, list, load, '
                  'release, reload, usage, version, or view'
         )
         parser.add_argument(
